@@ -67,7 +67,7 @@ classdef ClassificationPartitionedModel
 ## used for the training, e.g., @qcode{"ClassificationKNN"}.
 ##
 ## @item @qcode{KFold} @tab @tab Number of cross-validated folds,
-## specified as a positive interger scalar. Represents how many folds the
+## specified as a positive integer scalar. Represents how many folds the
 ## data was divided into for cross-validation purposes.
 ##
 ## @item @qcode{ModelParameters} @tab @tab Model parameters used during
@@ -152,7 +152,7 @@ classdef ClassificationPartitionedModel
       ## Set properties
       this.X = Mdl.X;
       this.Y = Mdl.Y;
-      this.KFold = get (Partition, "NumTestSets");
+      this.KFold = Partition.NumTestSets;
       this.Trained = cell (this.KFold, 1);
       this.ClassNames = Mdl.ClassNames;
       this.ResponseName = Mdl.ResponseName;
@@ -196,7 +196,7 @@ classdef ClassificationPartitionedModel
           ## Train model according to partition object
           for k = 1:this.KFold
             idx = training (this.Partition, k);
-            tmp = fitcdiscr (this.X(idx, :), this.Y(idx), args{:});
+            tmp = fitcdiscr (this.X(idx, :), this.Y(idx,:), args{:});
             this.Trained{k} = compact (tmp);
           endfor
 
@@ -230,7 +230,7 @@ classdef ClassificationPartitionedModel
           ## Train model according to partition object
           for k = 1:this.KFold
             idx = training (this.Partition, k);
-            tmp = fitcgam (this.X(idx, :), this.Y(idx), args{:});
+            tmp = fitcgam (this.X(idx, :), this.Y(idx,:), args{:});
             this.Trained{k} = compact (tmp);
           endfor
 
@@ -287,7 +287,7 @@ classdef ClassificationPartitionedModel
           ## Train model according to partition object
           for k = 1:this.KFold
             idx = training (this.Partition, k);
-            this.Trained{k} = fitcknn (this.X(idx, :), this.Y(idx), args{:});
+            this.Trained{k} = fitcknn (this.X(idx, :), this.Y(idx,:), args{:});
           endfor
 
           ## Store ModelParameters to ClassificationPartitionedModel object
@@ -322,7 +322,7 @@ classdef ClassificationPartitionedModel
           ## Train model according to partition object
           for k = 1:this.KFold
             idx = training (this.Partition, k);
-            tmp = fitcnet (this.X(idx, :), this.Y(idx), args{:});
+            tmp = fitcnet (this.X(idx, :), this.Y(idx,:), args{:});
             this.Trained{k} = compact (tmp);
           endfor
 
@@ -346,7 +346,7 @@ classdef ClassificationPartitionedModel
           for k = 1:this.KFold
             idx = training (this.Partition, k);
             ## Pass all arguments directly to fitcsvm
-            tmp = fitcsvm (this.X(idx, :), this.Y(idx), ...
+            tmp = fitcsvm (this.X(idx, :), this.Y(idx,:), ...
                            'Standardize', Mdl.Standardize, ...
                            'PredictorNames', Mdl.PredictorNames, ...
                            'ResponseName', Mdl.ResponseName, ...
@@ -407,9 +407,8 @@ classdef ClassificationPartitionedModel
     ## numeric matrix. Each row of @var{Cost} corresponds to an observation,
     ## and each column corresponds to a class. The value in row @var{i}
     ## and column @var{j} is the classification cost for class @var{j} for
-    ## observation @var{i}. This output is
-    ## optional and only returned if requested.
-    ##
+    ## observation @var{i}. This output is optional and only returned if
+    ## requested.
     ## @end multitable
     ##
     ## @seealso{ClassificationKNN, ClassificationSVM,
@@ -422,9 +421,9 @@ classdef ClassificationPartitionedModel
       no_cost_models = {'ClassificationNeuralNetwork', 'ClassificationSVM'};
       no_cost = any (strcmp (this.CrossValidatedModel, no_cost_models));
       if (no_cost && nargout > 2)
-        error (strcat (["ClassificationPartitionedModel.kfoldPredict:"], ...
-                       [" 'Cost' output is not supported for %s cross"], ...
-                       [" validated models."]), this.CrossValidatedModel);
+        error (strcat ("ClassificationPartitionedModel.kfoldPredict:", ...
+                       " 'Cost' output is not supported for %s cross", ...
+                       " validated models."), this.CrossValidatedModel);
       endif
 
       ## Initialize the label vector based on the type of Y
@@ -479,7 +478,8 @@ classdef ClassificationPartitionedModel
       ## Handle single fold case (holdout)
       if (this.KFold == 1)
         testIdx = test (this.Partition, 1);
-        label(testIdx) = mode (this.Y);
+        y = grp2idx (this.Y);
+        label(testIdx) = this.Y(find (y == mode (y), 1));
         Score(testIdx, :) = NaN;
         Cost(testIdx, :) = NaN;
         return;
@@ -550,13 +550,13 @@ endclassdef
 %! x = [1, 2, 3; 4, 5, 6; 7, 8, 9; 3, 2, 1];
 %! y = ["a"; "a"; "b"; "b"];
 %! a = fitcgam (x, y, "Interactions", "all");
-%! cvModel = crossval (a, "KFold", 5);
+%! cvModel = crossval (a, "KFold", 2);
 %! assert (class (cvModel), "ClassificationPartitionedModel");
 %! assert (cvModel.NumObservations, 4);
-%! assert (numel (cvModel.Trained), 5);
+%! assert (numel (cvModel.Trained), 2);
 %! assert (class (cvModel.Trained{1}), "CompactClassificationGAM");
 %! assert (cvModel.CrossValidatedModel, "ClassificationGAM");
-%! assert (cvModel.KFold, 5);
+%! assert (cvModel.KFold, 2);
 %!test
 %! x = [1, 2, 3; 4, 5, 6; 7, 8, 9; 3, 2, 1];
 %! y = ["a"; "a"; "b"; "b"];
@@ -572,7 +572,7 @@ endclassdef
 %! x = [1, 2, 3; 4, 5, 6; 7, 8, 9; 3, 2, 1];
 %! y = ["a"; "a"; "b"; "b"];
 %! a = fitcknn (x, y);
-%! partition = cvpartition (y, "KFold", 5);
+%! partition = cvpartition (y, "KFold", 2);
 %! cvModel = ClassificationPartitionedModel (a, partition);
 %! assert (class (cvModel), "ClassificationPartitionedModel");
 %! assert (class (cvModel.Trained{1}), "ClassificationKNN");
@@ -598,9 +598,9 @@ endclassdef
 %!test
 %! x = [1, 2, 3; 4, 5, 6; 7, 8, 9; 3, 2, 1];
 %! y = ["a"; "a"; "b"; "b"];
-%! k = 3;
+%! k = 2;
 %! a = fitcknn (x, y, "NumNeighbors" ,k);
-%! partition = cvpartition (y, "LeaveOut");
+%! partition = cvpartition (numel (y), "LeaveOut");
 %! cvModel = ClassificationPartitionedModel (a, partition);
 %! assert (class (cvModel), "ClassificationPartitionedModel");
 %! assert (class (cvModel.Trained{1}), "ClassificationKNN");
@@ -614,13 +614,13 @@ endclassdef
 %! x = [1, 2, 3; 4, 5, 6; 7, 8, 9; 3, 2, 1];
 %! y = {"a"; "a"; "b"; "b"};
 %! a = fitcnet (x, y, "IterationLimit", 50);
-%! cvModel = crossval (a, "KFold", 5);
+%! cvModel = crossval (a, "KFold", 2);
 %! assert (class (cvModel), "ClassificationPartitionedModel");
 %! assert (cvModel.NumObservations, 4);
-%! assert (numel (cvModel.Trained), 5);
+%! assert (numel (cvModel.Trained), 2);
 %! assert (class (cvModel.Trained{1}), "CompactClassificationNeuralNetwork");
 %! assert (cvModel.CrossValidatedModel, "ClassificationNeuralNetwork");
-%! assert (cvModel.KFold, 5);
+%! assert (cvModel.KFold, 2);
 %!test
 %! x = [1, 2, 3; 4, 5, 6; 7, 8, 9; 3, 2, 1];
 %! y = {"a"; "a"; "b"; "b"};
@@ -698,7 +698,7 @@ endclassdef
 %! y = {"a"; "a"; "b"; "b"};
 %! k = 3;
 %! a = fitcknn (x, y, "NumNeighbors", k);
-%! partition = cvpartition (y, "LeaveOut");
+%! partition = cvpartition (numel (y), "LeaveOut");
 %! cvModel = ClassificationPartitionedModel (a, partition);
 %! [label, score, cost] = kfoldPredict (cvModel);
 %! assert (class(cvModel), "ClassificationPartitionedModel");
