@@ -1,4 +1,5 @@
-## Copyright (C) 2024 Andreas Bertsatos <abertsatos@biol.uoa.gr>
+## Copyright (C) 2024-2025 Andreas Bertsatos <abertsatos@biol.uoa.gr>
+## Copyright (C) 2025 Swayam Shah <swayamshah66@gmail.com>
 ##
 ## This file is part of the statistics package for GNU Octave.
 ##
@@ -17,102 +18,221 @@
 
 classdef LogisticDistribution
   ## -*- texinfo -*-
-  ## @deftypefn {statistics} LogisticDistribution
+  ## @deftp {statistics} LogisticDistribution
   ##
   ## Logistic probability distribution object.
   ##
   ## A @code{LogisticDistribution} object consists of parameters, a model
   ## description, and sample data for a logistic probability distribution.
   ##
-  ## The logistic distribution uses the following parameters.
+  ## The logistic distribution is a continuous probability distribution, which
+  ## is commonly used in logistic regression and feedforward neural networks.
+  ## It is defined by location parameter @var{mu} and scale parameter
+  ## @var{sigma}.
   ##
-  ## @multitable @columnfractions 0.25 0.48 0.27
-  ## @headitem @var{Parameter} @tab @var{Description} @tab @var{Support}
-  ##
-  ## @item @qcode{mu} @tab Mean of logarithmic values @tab @math{mu >= 0}
-  ## @item @qcode{sigma} @tab Scale of logarithmic values @tab @math{sigma > 0}
-  ## @end multitable
-  ##
-  ## There are several ways to create a @code{LogisticDistribution} object.
+  ## There are several ways to create a @code{LogisticDistribution}
+  ## object.
   ##
   ## @itemize
   ## @item Fit a distribution to data using the @code{fitdist} function.
-  ## @item Create a distribution with specified parameter values using the
+  ## @item Create a distribution with fixed parameter values using the
   ## @code{makedist} function.
-  ## @item Use the constructor @qcode{LogisticDistribution (@var{mu}, @var{sigma})}
-  ## to create a logistic distribution with specified parameter values.
+  ## @item Use the constructor @qcode{LogisticDistribution (@var{mu},
+  ## @var{sigma})} to create a logistic distribution with fixed parameter values
+  ## @var{mu} and @var{sigma}.
   ## @item Use the static method @qcode{LogisticDistribution.fit (@var{x},
-  ## @var{censor}, @var{freq}, @var{options})} to a distribution to data @var{x}.
+  ## @var{alpha}, @var{censor}, @var{freq}, @var{options})} to fit a
+  ## distribution to the data in @var{x} using the same input arguments as the
+  ## @code{logifit} function.
   ## @end itemize
   ##
   ## It is highly recommended to use @code{fitdist} and @code{makedist}
-  ## functions to create probability distribution objects, instead of the
-  ## constructor and the aforementioned static method.
-  ##
-  ## A @code{LogisticDistribution} object contains the following properties,
-  ## which can be accessed using dot notation.
-  ##
-  ## @multitable @columnfractions 0.25 0.25 0.25 0.25
-  ## @item @qcode{DistributionName} @tab @qcode{DistributionCode} @tab
-  ## @qcode{NumParameters} @tab @qcode{ParameterNames}
-  ## @item @qcode{ParameterDescription} @tab @qcode{ParameterValues} @tab
-  ## @qcode{ParameterValues} @tab @qcode{ParameterCI}
-  ## @item @qcode{ParameterIsFixed} @tab @qcode{Truncation} @tab
-  ## @qcode{IsTruncated} @tab @qcode{InputData}
-  ## @end multitable
-  ##
-  ## A @code{LogisticDistribution} object contains the following methods:
-  ## @code{cdf}, @code{icdf}, @code{iqr}, @code{mean}, @code{median},
-  ## @code{negloglik}, @code{paramci}, @code{pdf}, @code{plot}, @code{proflik},
-  ## @code{random}, @code{std}, @code{truncate}, @code{var}.
+  ## functions to create probability distribution objects, instead of the class
+  ## constructor or the aforementioned static method.
   ##
   ## Further information about the logistic distribution can be found at
   ## @url{https://en.wikipedia.org/wiki/Logistic_distribution}
   ##
-  ## OCTAVE/MATLAB use an alternative parameterization given by the pair
-  ## @math{μ, s}, i.e. @var{mu} and @var{sigma}, in analogy with the logistic
-  ## distribution.  Their relation to the @math{α} and @math{b} parameters used
-  ## in Wikipedia are given below:
-  ##
-  ## @itemize
-  ## @item @qcode{@var{mu} = log (@var{a})}
-  ## @item @qcode{@var{sigma} = 1 / @var{a}}
-  ## @end itemize
-  ##
-  ## @seealso{fitdist, makedist, logicdf, logiinv, logipdf, logirnd, lognfit,
+  ## @seealso{fitdist, makedist, logicdf, logiinv, logipdf, logirnd, logifit,
   ## logilike, logistat}
-  ## @end deftypefn
+  ## @end deftp
 
   properties (Dependent = true)
+    ## -*- texinfo -*-
+    ## @deftp {LogisticDistribution} {property} mu
+    ##
+    ## Location parameter
+    ##
+    ## A scalar value characterizing the location of the
+    ## logistic distribution. You can access the @qcode{mu}
+    ## property using dot name assignment.
+    ##
+    ## @end deftp
     mu
+
+    ## -*- texinfo -*-
+    ## @deftp {LogisticDistribution} {property} sigma
+    ##
+    ## Scale parameter
+    ##
+    ## A positive scalar value characterizing the scale of the
+    ## logistic distribution. You can access the @qcode{sigma}
+    ## property using dot name assignment.
+    ##
+    ## @end deftp
     sigma
   endproperties
 
   properties (GetAccess = public, Constant = true)
-    CensoringAllowed = true;
+    ## -*- texinfo -*-
+    ## @deftp {LogisticDistribution} {property} DistributionName
+    ##
+    ## Probability distribution name
+    ##
+    ## A character vector specifying the name of the probability distribution
+    ## object. This property is read-only.
+    ##
+    ## @end deftp
     DistributionName = "LogisticDistribution";
-    DistributionCode = "logi";
+
+    ## -*- texinfo -*-
+    ## @deftp {LogisticDistribution} {property} NumParameters
+    ##
+    ## Number of parameters
+    ##
+    ## A scalar integer value specifying the number of parameters characterizing
+    ## the probability distribution. This property is read-only.
+    ##
+    ## @end deftp
     NumParameters = 2;
+
+    ## -*- texinfo -*-
+    ## @deftp {LogisticDistribution} {property} ParameterNames
+    ##
+    ## Names of parameters
+    ##
+    ## A @math{2x1} cell array of character vectors with each element containing
+    ## the name of a distribution parameter. This property is read-only.
+    ##
+    ## @end deftp
     ParameterNames = {"mu", "sigma"};
-    ParameterDescription = {"Mean of logarithmic values", ...
-                            "Scale of logarithmic values"};
+
+    ## -*- texinfo -*-
+    ## @deftp {LogisticDistribution} {property} ParameterDescription
+    ##
+    ## Description of parameters
+    ##
+    ## A @math{2x1} cell array of character vectors with each element containing
+    ## a short description of a distribution parameter. This property is
+    ## read-only.
+    ##
+    ## @end deftp
+    ParameterDescription = {"Location", "Scale"};
   endproperties
 
-  properties (GetAccess = public, Constant = true)
-    ParameterRange = [0, realmin; Inf, Inf];
+  properties (GetAccess = public, Constant = true, Hidden)
+    CensoringAllowed = true;
+    DistributionCode = "logi";
+    ParameterRange = [-Inf, realmin; Inf, Inf];
     ParameterLogCI = [true, true];
   endproperties
 
-  properties (GetAccess = public , SetAccess = protected)
+  properties (GetAccess = public, SetAccess = protected)
+    ## -*- texinfo -*-
+    ## @deftp {LogisticDistribution} {property} ParameterValues
+    ##
+    ## Distribution parameter values
+    ##
+    ## A @math{2x1} numeric vector containing the values of the distribution
+    ## parameters. This property is read-only. You can change the distribution
+    ## parameters by assigning new values to the @qcode{mu} and @qcode{sigma}
+    ## properties.
+    ##
+    ## @end deftp
     ParameterValues
-    ParameterCI
+
+    ## -*- texinfo -*-
+    ## @deftp {LogisticDistribution} {property} ParameterCovariance
+    ##
+    ## Covariance matrix of the parameter estimates
+    ##
+    ## A @math{2x2} numeric matrix containing the variance-covariance of the
+    ## parameter estimates. Diagonal elements contain the variance of each
+    ## estimated parameter, and non-diagonal elements contain the covariance
+    ## between the parameter estimates. The covariance matrix is only meaningful
+    ## when the distribution was fitted to data. If the distribution object was
+    ## created with fixed parameters, or a parameter of a fitted distribution is
+    ## modified, then all elements of the variance-covariance are zero. This
+    ## property is read-only.
+    ##
+    ## @end deftp
     ParameterCovariance
+
+    ## -*- texinfo -*-
+    ## @deftp {LogisticDistribution} {property} ParameterIsFixed
+    ##
+    ## Flag for fixed parameters
+    ##
+    ## A @math{1x2} logical vector specifying which parameters are fixed and
+    ## which are estimated. @qcode{true} values correspond to fixed parameters,
+    ## @qcode{false} values correspond to parameter estimates. This property is
+    ## read-only.
+    ##
+    ## @end deftp
     ParameterIsFixed
+
+    ## -*- texinfo -*-
+    ## @deftp {LogisticDistribution} {property} Truncation
+    ##
+    ## Truncation interval
+    ##
+    ## A @math{1x2} numeric vector specifying the truncation interval for the
+    ## probability distribution. First element contains the lower boundary,
+    ## second element contains the upper boundary. This property is read-only.
+    ## You can only truncate a probability distribution with the
+    ## @qcode{truncate} method.
+    ##
+    ## @end deftp
     Truncation
+
+    ## -*- texinfo -*-
+    ## @deftp {LogisticDistribution} {property} IsTruncated
+    ##
+    ## Flag for truncated probability distribution
+    ##
+    ## A logical scalar value specifying whether a probability distribution is
+    ## truncated or not. This property is read-only.
+    ##
+    ## @end deftp
     IsTruncated
+
+    ## -*- texinfo -*-
+    ## @deftp {LogisticDistribution} {property} InputData
+    ##
+    ## Data used for fitting a probability distribution
+    ##
+    ## A scalar structure containing the following fields:
+    ## @itemize
+    ## @item @qcode{data}: a numeric vector containing the data used for
+    ## distribution fitting.
+    ## @item @qcode{cens}: a numeric vector of logical values indicating
+    ## censoring information corresponding to the elements of the data used for
+    ## distribution fitting. If no censoring vector was used for distribution
+    ## fitting, then this field defaults to an empty array.
+    ## @item @qcode{freq}: a numeric vector of non-negative integer values
+    ## containing the frequency information corresponding to the elements of the
+    ## data used for distribution fitting. If no frequency vector was used for
+    ## distribution fitting, then this field defaults to an empty array.
+    ## @end itemize
+    ##
+    ## @end deftp
     InputData
   endproperties
 
+  properties (GetAccess = public, SetAccess = protected, Hidden)
+    ParameterCI
+  endproperties
+
   methods (Hidden)
 
     function this = LogisticDistribution (mu, sigma)
@@ -211,13 +331,13 @@ classdef LogisticDistribution
     endfunction
 
     ## -*- texinfo -*-
-    ## @deftypefn  {LogisticDistribution} {@var{p} =} icdf (@var{pd}, @var{p})
+    ## @deftypefn  {LogisticDistribution} {@var{x} =} icdf (@var{pd}, @var{p})
     ##
     ## Compute the inverse cumulative distribution function (iCDF).
     ##
-    ## @code{@var{p} = icdf (@var{pd}, @var{x})} computes the quantile (the
+    ## @code{@var{x} = icdf (@var{pd}, @var{p})} computes the quantile (the
     ## inverse of the CDF) of the probability distribution object, @var{pd},
-    ## evaluated at the values in @var{x}.
+    ## evaluated at the values in @var{p}.
     ##
     ## @end deftypefn
     function x = icdf (this, p)
@@ -304,8 +424,8 @@ classdef LogisticDistribution
     ##
     ## Compute the negative loglikelihood of a probability distribution.
     ##
-    ## @code{@var{m} = negloglik (@var{pd})} computes the negative loglikelihood
-    ## of the probability distribution object, @var{pd}.
+    ## @code{@var{nlogL} = negloglik (@var{pd})} computes the negative
+    ## loglikelihood of the probability distribution object, @var{pd}.
     ##
     ## @end deftypefn
     function nlogL = negloglik (this)
@@ -331,7 +451,7 @@ classdef LogisticDistribution
     ## probability distribution object, @var{pd}.
     ##
     ## @code{@var{ci} = paramci (@var{pd}, @var{Name}, @var{Value})} computes the
-    ## confidence intervals with additional options specified specified by
+    ## confidence intervals with additional options specified by
     ## @qcode{Name-Value} pair arguments listed below.
     ##
     ## @multitable @columnfractions 0.18 0.02 0.8
@@ -394,7 +514,7 @@ classdef LogisticDistribution
     ##
     ## Plot a probability distribution object.
     ##
-    ## @code{plot (@var{pd}} plots a probability density function (PDF) of the
+    ## @code{plot (@var{pd})} plots a probability density function (PDF) of the
     ## probability distribution object @var{pd}.  If @var{pd} contains data,
     ## which have been fitted by @code{fitdist}, the PDF is superimposed over a
     ## histogram of the data.
@@ -403,7 +523,7 @@ classdef LogisticDistribution
     ## options with the @qcode{Name-Value} pair arguments listed below.
     ##
     ## @multitable @columnfractions 0.18 0.02 0.8
-    ## @headitem @tab @var{Name} @tab @var{Value}
+    ## @headitem @var{Name} @tab @tab @var{Value}
     ##
     ## @item @qcode{"PlotType"} @tab @tab A character vector specifying the plot
     ## type.  @qcode{"pdf"} plots the probability density function (PDF).  When
@@ -467,9 +587,9 @@ classdef LogisticDistribution
     ## @var{setparam}, @qcode{"Display"}, @qcode{"on"})} also plots the profile
     ## likelihood against the user-defined range of the selected parameter.
     ##
-    ## For the logistic distribution, @qcode{@var{pnum} = 1} selects the
-    ## parameter @qcode{mu} and @qcode{@var{pnum} = 2} selects the parameter
-    ## @var{sigma}.
+    ## For the logistic distribution, @qcode{@var{pnum} = 1} selects
+    ## the parameter @qcode{mu} and @qcode{@var{pnum} = 2} selects the
+    ## parameter @qcode{sigma}.
     ##
     ## When opted to display the profile likelihood plot, @code{proflik} also
     ## plots the baseline loglikelihood computed at the lower bound of the 95%
@@ -489,17 +609,17 @@ classdef LogisticDistribution
     endfunction
 
     ## -*- texinfo -*-
-    ## @deftypefn  {LogisticDistribution} {@var{y} =} random (@var{pd})
-    ## @deftypefnx {LogisticDistribution} {@var{y} =} random (@var{pd}, @var{rows})
-    ## @deftypefnx {LogisticDistribution} {@var{y} =} random (@var{pd}, @var{rows}, @var{cols}, @dots{})
-    ## @deftypefnx {LogisticDistribution} {@var{y} =} random (@var{pd}, [@var{sz}])
+    ## @deftypefn  {LogisticDistribution} {@var{r} =} random (@var{pd})
+    ## @deftypefnx {LogisticDistribution} {@var{r} =} random (@var{pd}, @var{rows})
+    ## @deftypefnx {LogisticDistribution} {@var{r} =} random (@var{pd}, @var{rows}, @var{cols}, @dots{})
+    ## @deftypefnx {LogisticDistribution} {@var{r} =} random (@var{pd}, [@var{sz}])
     ##
     ## Generate random arrays from the probability distribution object.
     ##
     ## @code{@var{r} = random (@var{pd})} returns a random number from the
     ## distribution object @var{pd}.
     ##
-    ## When called with a single size argument, @code{betarnd} returns a square
+    ## When called with a single size argument, @code{bisarnd} returns a square
     ## matrix with the dimension specified.  When called with more than one
     ## scalar argument, the first two arguments are taken as the number of rows
     ## and columns and any further arguments specify additional matrix
@@ -543,13 +663,14 @@ classdef LogisticDistribution
     ##
     ## Truncate a probability distribution.
     ##
-    ## @code{@var{t} = truncate (@var{pd})} returns a probability distribution
-    ## @var{t}, which is the probability distribution @var{pd} truncated to the
-    ## specified interval with lower limit, @var{lower}, and upper limit,
-    ## @var{upper}.  If @var{pd} is fitted to data with @code{fitdist}, the
-    ## returned probability distribution @var{t} is not fitted, does not contain
-    ## any data or estimated values, and it is as it has been created with the
-    ## @var{makedist} function, but it includes the truncation interval.
+    ## @code{@var{t} = truncate (@var{pd}, @var{lower}, @var{upper})} returns a
+    ## probability distribution @var{t}, which is the probability distribution
+    ## @var{pd} truncated to the specified interval with lower limit, @var{lower},
+    ## and upper limit, @var{upper}.  If @var{pd} is fitted to data with
+    ## @code{fitdist}, the returned probability distribution @var{t} is not
+    ## fitted, does not contain any data or estimated values, and it is as it
+    ## has been created with the @var{makedist} function, but it includes the
+    ## truncation interval.
     ##
     ## @end deftypefn
     function this = truncate (this, lower, upper)
@@ -573,7 +694,7 @@ classdef LogisticDistribution
     ##
     ## Compute the variance of a probability distribution.
     ##
-    ## @code{@var{v} = var (@var{pd})} computes the standard deviation of the
+    ## @code{@var{v} = var (@var{pd})} computes the variance of the
     ## probability distribution object, @var{pd}.
     ##
     ## @end deftypefn
@@ -643,9 +764,8 @@ classdef LogisticDistribution
 endclassdef
 
 function checkparams (mu, sigma)
-  if (! (isscalar (mu) && isnumeric (mu) && isreal (mu) && isfinite (mu)
-                       && mu >= 0))
-    error ("LogisticDistribution: MU must be a nonnegative real scalar.")
+  if (! (isscalar (mu) && isnumeric (mu) && isreal (mu) && isfinite (mu)))
+    error ("LogisticDistribution: MU must be a finite real scalar.")
   endif
   if (! (isscalar (sigma) && isnumeric (sigma) && isreal (sigma)
                           && isfinite (sigma) && sigma > 0))
@@ -685,15 +805,15 @@ endfunction
 
 ## Test input validation
 ## 'LogisticDistribution' constructor
-%!error <LogisticDistribution: MU must be a nonnegative real scalar.> ...
+%!error <LogisticDistribution: MU must be a finite real scalar.> ...
 %! LogisticDistribution(Inf, 1)
-%!error <LogisticDistribution: MU must be a nonnegative real scalar.> ...
+%!error <LogisticDistribution: MU must be a finite real scalar.> ...
 %! LogisticDistribution(i, 1)
-%!error <LogisticDistribution: MU must be a nonnegative real scalar.> ...
+%!error <LogisticDistribution: MU must be a finite real scalar.> ...
 %! LogisticDistribution("a", 1)
-%!error <LogisticDistribution: MU must be a nonnegative real scalar.> ...
+%!error <LogisticDistribution: MU must be a finite real scalar.> ...
 %! LogisticDistribution([1, 2], 1)
-%!error <LogisticDistribution: MU must be a nonnegative real scalar.> ...
+%!error <LogisticDistribution: MU must be a finite real scalar.> ...
 %! LogisticDistribution(NaN, 1)
 %!error <LogisticDistribution: SIGMA must be a positive real scalar.> ...
 %! LogisticDistribution(1, 0)
