@@ -115,8 +115,8 @@ function [lb, ub, xmin, xmax] = compute_boundaries (pd)
   xmin = m - 3.5 * s;
   xmax = m + 3.5 * s;
   ## Fix boundaries for specific distributions
-  PD = {"bino", "bisa", "exp", "gam", "invg", "logl", ...
-        "logn", "naka", "nbin", "poiss", "rayl", "rice", "wbl"};
+  PD = {"bino", "bisa", "exp", "gam", "invg", "logl", "logn", ...
+        "naka", "nbin", "poiss", "rayl", "rice", "wbl"};
   if (strcmpi (pd.DistributionCode, "beta"))
     lb = xmin = 0;
     ub = xmax = 1;
@@ -213,7 +213,7 @@ function h = plot_pdf (pd, ax, DistType, Discrete)
     ## Plot
     if (Discrete)
       h = stem (ax, x, y, "color", "r");
-      xlim ([min(y)-0.5, max(y)+0.5]);
+      xlim ([min(x)-0.5, max(x)+0.5]);
       xlabel ("Data");
       ylabel ("Probability");
     else
